<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="zh_TW">
<context>
    <name>API</name>
    <message>
        <source>Please log in with your Deepin ID.</source>
        <translation>請登入您的Deepin ID帳號</translation>
    </message>
    <message>
        <source>You need to log in to proceed with the subsequent operations.</source>
        <translation>您需要登入才能進行後續操作。</translation>
    </message>
</context>
<context>
    <name>APIProxy</name>
    <message>
        <source>You have been making too many requests, Please try again later.</source>
        <translation>您的操作太頻繁了，請稍後再試。</translation>
    </message>
    <message>
        <source>You need to login to proceed with the subsequent operations.</source>
        <translation>您需要登入才能進行後續操作。</translation>
    </message>
    <message>
        <source>Network error, please try later.</source>
        <translation>網路錯誤，請稍後再試</translation>
    </message>
</context>
<context>
    <name>AccountButton</name>
    <message>
        <source>Unlogged</source>
        <translation>未登入</translation>
    </message>
    <message>
        <source>My Favorites</source>
        <translation>我的收藏</translation>
    </message>
    <message>
        <source>My Feedbacks</source>
        <translation>我的回饋</translation>
    </message>
    <message>
        <source>Sign out</source>
        <translation>退出帳號</translation>
    </message>
    <message>
        <source>Sign in</source>
        <translation>登入帳號</translation>
    </message>
</context>
<context>
    <name>Card</name>
    <message>
        <source>%1 views</source>
        <translation>%1次查看</translation>
    </message>
    <message>
        <source>Suggestions</source>
        <translation>需求</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>取消收藏</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>收藏</translation>
    </message>
    <message>
        <source>Cancel the urge</source>
        <translation>不催了</translation>
    </message>
    <message>
        <source>Urge</source>
        <translation>催一下</translation>
    </message>
</context>
<context>
    <name>Card1</name>
    <message>
        <source>Coming</source>
        <translation>敬請期待</translation>
    </message>
</context>
<context>
    <name>Detail</name>
    <message>
        <source>Official response</source>
        <translation>官方回復</translation>
    </message>
</context>
<context>
    <name>Filter</name>
    <message>
        <source>Search</source>
        <translation>搜索</translation>
    </message>
    <message>
        <source>Type:</source>
        <translation>類型：</translation>
    </message>
    <message>
        <source>All</source>
        <translation>全部</translation>
    </message>
    <message>
        <source>Bug</source>
        <translation>BUG</translation>
    </message>
    <message>
        <source>Suggestions</source>
        <translation>需求回饋</translation>
    </message>
    <message>
        <source>Version:</source>
        <translation>版本：</translation>
    </message>
    <message>
        <source>Sort:</source>
        <translation>排序：</translation>
    </message>
    <message>
        <source>Newest</source>
        <translation>最新</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>收藏</translation>
    </message>
    <message>
        <source>Urge</source>
        <translation>催一下</translation>
    </message>
</context>
<context>
    <name>Index</name>
    <message>
        <source>Communication</source>
        <translation>互動交流</translation>
    </message>
    <message>
        <source>Discuss and share here</source>
        <translation>社群使用者交流分享</translation>
    </message>
    <message>
        <source>Bug Report</source>
        <translation>Bug回饋</translation>
    </message>
    <message>
        <source>Report issues you found</source>
        <translation>日常使用問題回饋</translation>
    </message>
    <message>
        <source>Suggestions</source>
        <translation>需求回饋</translation>
    </message>
    <message>
        <source>Submit your suggestions</source>
        <translation>對作業系統的好建議</translation>
    </message>
    <message>
        <source>Resources</source>
        <translation>社群相關</translation>
    </message>
    <message>
        <source>Questionaire</source>
        <translation>問卷調查</translation>
    </message>
    <message>
        <source>Join US</source>
        <translation>加入我們</translation>
    </message>
    <message>
        <source>Internal Testing</source>
        <translation>內測交流</translation>
    </message>
    <message>
        <source>Global Translation</source>
        <translation>全球化翻譯</translation>
    </message>
    <message>
        <source>Community News</source>
        <translation>社群動態</translation>
    </message>
</context>
<context>
    <name>List</name>
    <message>
        <source>No more items</source>
        <translation>沒有更多了</translation>
    </message>
    <message>
        <source>Messages</source>
        <translation>系統消息</translation>
    </message>
    <message>
        <source>Questionaires</source>
        <translation>調查問卷</translation>
    </message>
</context>
<context>
    <name>MyTitleBar</name>
    <message>
        <source>Launch at system startup</source>
        <translation>開機自啟</translation>
    </message>
    <message>
        <source>About</source>
        <translation>關於</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>退出</translation>
    </message>
    <message>
        <source>Deepin Home</source>
        <translation>深度之家</translation>
    </message>
    <message>
        <source>Quick login to forums, submit suggestions, and report bugs.</source>
        <translation>快速登入論壇、提需求和報Bug。</translation>
    </message>
</context>
<context>
    <name>Notify</name>
    <message>
        <source>No messages yet.</source>
        <translation>目前無通知訊息，感謝您的關注！</translation>
    </message>
    <message>
        <source>%1 messages</source>
        <translation>共%1條</translation>
    </message>
    <message>
        <source>Mark all as read</source>
        <translation>一鍵已讀</translation>
    </message>
</context>
<context>
    <name>NotifyDetail</name>
    <message>
        <source>View more</source>
        <translation>查看更多</translation>
    </message>
</context>
<context>
    <name>Offline</name>
    <message>
        <source>Network error, please try later</source>
        <translation>網路錯誤，請稍後再試</translation>
    </message>
    <message>
        <source>Refresh</source>
        <translation>重新整理</translation>
    </message>
</context>
<context>
    <name>Preload</name>
    <message>
        <source>Deepin Home</source>
        <translation>深度之家</translation>
    </message>
</context>
<context>
    <name>Questionnaire</name>
    <message>
        <source>No questionaires yet.</source>
        <translation>目前無問卷訊息，感謝您的關注！</translation>
    </message>
    <message>
        <source>Expired on: %1</source>
        <translation>有效期至：%1</translation>
    </message>
    <message>
        <source>Fill In</source>
        <translation>填寫</translation>
    </message>
</context>
<context>
    <name>Status</name>
    <message>
        <source>Pending</source>
        <translation>待處理</translation>
    </message>
    <message>
        <source>Reproducing</source>
        <translation>復現中</translation>
    </message>
    <message>
        <source>Confirmed</source>
        <translation>已確認</translation>
    </message>
    <message>
        <source>Replied</source>
        <translation>已回復</translation>
    </message>
    <message>
        <source>Resolved</source>
        <translation>已解決</translation>
    </message>
    <message>
        <source>Evaluating</source>
        <translation>評估中</translation>
    </message>
    <message>
        <source>Accepted</source>
        <translation>已接受</translation>
    </message>
    <message>
        <source>Completed</source>
        <translation>已完成</translation>
    </message>
    <message>
        <source>The issue has not been processed and will not be displayed in the public listing.</source>
        <translation>問題未做任何處理，不會出現在需求廣場</translation>
    </message>
    <message>
        <source>Currently unable to identify the cause; continuous monitoring and investigation are required.</source>
        <translation>暫時無法定位，需持續跟進問題</translation>
    </message>
    <message>
        <source>The issue has been reproduced and the root cause has been identified.</source>
        <translation>明確復現並已經定位原因</translation>
    </message>
    <message>
        <source>The issue is not a bug or of a different nature.</source>
        <translation>非Bug類型問題</translation>
    </message>
    <message>
        <source>The issue has been resolved and awaiting formal release</source>
        <translation>完成修復，待推送內容</translation>
    </message>
    <message>
        <source>The requirement has not been processed and will not be displayed in the public listing</source>
        <translation>需求未做任何處理，不會出現在需求廣場</translation>
    </message>
    <message>
        <source>The issue has been acknowledged and is being internally assessed</source>
        <translation>已經明確接受並轉入內部需求評估</translation>
    </message>
    <message>
        <source>Included in the plans for a future release</source>
        <translation>納入後期版本規劃</translation>
    </message>
    <message>
        <source>The requirement is either not accepted or unable to be addressed</source>
        <translation>暫不接受或無法處理需求問題</translation>
    </message>
    <message>
        <source>Development work is finished, awaiting formal release</source>
        <translation>完成開發，待正式發布</translation>
    </message>
</context>
<context>
    <name>Submit</name>
    <message>
        <source>Unable to add a screenshot.</source>
        <translation>無法添加截圖</translation>
    </message>
    <message>
        <source>The image file size should be less than 1MB.</source>
        <translation>圖像檔案大小應小於 1MB</translation>
    </message>
    <message>
        <source>The image file format is not supported for uploading.</source>
        <translation>圖片的檔案格式不支援上傳</translation>
    </message>
    <message>
        <source>[Current Status of the Product]: 
[Desired Product]: </source>
        <translation>【產品現狀】：
【產品期望】： </translation>
    </message>
    <message>
        <source>[Preconditions]: 
[Reproducibility Steps]: 
[Expected Results]: 
[Actual Results]: </source>
        <translation>【前置條件】：
【復現步驟】：
【預期結果】： 
【實際結果】： </translation>
    </message>
    <message>
        <source>Submit Feedback</source>
        <translation>提交回饋</translation>
    </message>
    <message>
        <source>Type：</source>
        <translation>類型：</translation>
    </message>
    <message>
        <source>Suggestions</source>
        <translation>需求回饋</translation>
    </message>
    <message>
        <source>Bug Report</source>
        <translation>BUG回饋</translation>
    </message>
    <message>
        <source>Title：</source>
        <translation>標題：</translation>
    </message>
    <message>
        <source>Please provide a brief description of your issue</source>
        <translation>請簡單描述你的問題</translation>
    </message>
    <message>
        <source>Content：</source>
        <translation>內容：</translation>
    </message>
    <message>
        <source>Do not fill in multiple issues in one feedback</source>
        <translation>請勿在一條回饋中填寫多個問題</translation>
    </message>
    <message>
        <source>Do not fill in multiple requirements in one feedback</source>
        <translation>請勿在一條回饋中填寫多條需求</translation>
    </message>
    <message>
        <source>Email：</source>
        <translation>信箱：</translation>
    </message>
    <message>
        <source>Please enter your email</source>
        <translation>請輸入您的電子郵件</translation>
    </message>
    <message>
        <source>System Version:</source>
        <translation>系統版本：</translation>
    </message>
    <message>
        <source>Device Info：</source>
        <translation>裝置訊息：</translation>
    </message>
    <message>
        <source>Upload &lt;a href=&apos;home://sysinfo&apos;&gt;device information&lt;/a&gt;</source>
        <translation>上傳&lt;a href=&apos;home://sysinfo&apos;&gt;裝置訊息&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Screenshots：</source>
        <translation>截圖：</translation>
    </message>
    <message>
        <source>Image files</source>
        <translation>圖片文件</translation>
    </message>
    <message>
        <source>Drag and drop files or click buttons to add pictures, up to three</source>
        <translation>拖曳文件或者點擊“+”添加圖片，最多添加三張</translation>
    </message>
    <message>
        <source>Are you sure you want to exit the feedback submission?</source>
        <translation>您確定要退出回饋訊息建立嗎？</translation>
    </message>
    <message>
        <source>The feedback content will not be saved.</source>
        <translation>回饋內容不會被儲存</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>退出</translation>
    </message>
    <message>
        <source>Submit</source>
        <translation>提交</translation>
    </message>
    <message>
        <source>Unable to submit feedback.</source>
        <translation>無法提交回饋</translation>
    </message>
    <message>
        <source>Please provide the title and content of your feedback.</source>
        <translation>請填寫回饋的標題和內容</translation>
    </message>
    <message>
        <source>Please provide the title of your feedback.</source>
        <translation>請填寫回饋的標題</translation>
    </message>
    <message>
        <source>Please provide the content of your feedback.</source>
        <translation>請填寫回饋的內容</translation>
    </message>
    <message>
        <source>Incorrect email address entered.</source>
        <translation>輸入的郵件地址不正確</translation>
    </message>
    <message>
        <source>Device Information</source>
        <translation>裝置訊息</translation>
    </message>
</context>
<context>
    <name>TabButton</name>
    <message>
        <source>Feedback Hub</source>
        <translation>回饋廣場</translation>
    </message>
    <message>
        <source>My Feedbacks</source>
        <translation>我的回饋</translation>
    </message>
    <message>
        <source>My Favorites</source>
        <translation>我的收藏</translation>
    </message>
    <message>
        <source>My Urged</source>
        <translation>我的催促</translation>
    </message>
</context>
</TS>